CellRefNode class

Represents a single cell or column reference in a formula AST.

A CellRefNode refers to a cell or column whose value is resolved at evaluation time by the formula engine.

Supported reference formats include:

  • A1-style references (e.g. A1, C5)
  • Bare column references (e.g. A, TOTAL)
  • Named column references (e.g. SALES, YEAR)
Inheritance

Constructors

CellRefNode(String reference)

Properties

hashCode int
The hash code for this object.
no setterinherited
reference String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited