CellChangeRecord class
Constructors
-
CellChangeRecord({required String changeId, required ValueKey<
String> rowKey, required ValueKey<String> columnKey, required int rowIndex, required int columnIndex, required String columnName, required dynamic oldValue, required dynamic newValue, required DateTime timestamp, String? userId, String? userName, required String changeType, String? reason}) -
CellChangeRecord.fromJson(Map<
String, dynamic> json) -
factory
Properties
- changeId → String
-
final
- changeType → String
-
final
- columnIndex → int
-
final
-
columnKey
→ ValueKey<
String> -
final
- columnName → String
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- newValue → dynamic
-
final
- oldValue → dynamic
-
final
- reason → String?
-
final
- rowIndex → int
-
final
-
rowKey
→ ValueKey<
String> -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- timestamp → DateTime
-
final
- userId → String?
-
final
- userName → String?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited