TokenType enum
Values
- cellReference → const TokenType
- columnReference → const TokenType
- rangeReference → const TokenType
- function → const TokenType
- number → const TokenType
- operator → const TokenType
- comparator → const TokenType
- string → const TokenType
- comma → const TokenType
- leftParen → const TokenType
- rightParen → const TokenType
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited